@@ -1,12 +1,10 @@
-context("plm tidiers")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("plm")
-library(plm)
+suppressPackageStartupMessages(library(plm))
 
 data(Produc, package = "plm")
 fit <- plm(
