@@ -1,12 +1,11 @@
-context("polca")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("poLCA")
-library(poLCA)
+skip_if_not_installed("MASS")
+suppressPackageStartupMessages(library(poLCA))
 
 data(values)
 fit <- poLCA(cbind(A, B, C, D) ~ 1, values, nclass = 2, verbose = FALSE)
